@@ -25,7 +25,7 @@ from merlin.core.utils import (
     global_dask_client,
     set_client_deprecated,
 )
-from merlin.dag import ColumnSelector, Node
+from merlin.dag import ColumnSelector, Graph, Node
 from merlin.io.worker import clean_worker_cache
 
 LOG = logging.getLogger("merlin")
@@ -39,7 +39,7 @@ class LocalExecutor:
     def transform(
         self,
         transformable,
-        nodes,
+        graph,
         output_dtypes=None,
         additional_columns=None,
         capture_dtypes=False,
@@ -48,6 +48,21 @@ class LocalExecutor:
         Transforms a single dataframe (possibly a partition of a Dask Dataframe)
         by applying the operators from a collection of Nodes
         """
+        nodes = []
+        if isinstance(graph, Graph):
+            nodes.append(graph.output_node)
+        elif isinstance(graph, Node):
+            nodes.append(graph)
+        elif isinstance(graph, list):
+            nodes = graph
+        else:
+            raise TypeError(
+                f"LocalExecutor detected unsupported type of input for graph: {type(graph)}."
+                " `graph` argument must be either a `Graph` object (preferred)"
+                " or a list of `Node` objects (deprecated, but supported for backward "
+                " compatibility.)"
+            )
+
         output_data = None
 
         for node in nodes:
@@ -120,7 +135,8 @@ class LocalExecutor:
         else:
             # If there are no parents, this is an input node,
             # so pull columns directly from root data
-            input_data = transformable[node_input_cols + list(addl_input_cols)]
+            addl_input_cols = list(addl_input_cols) if addl_input_cols else []
+            input_data = transformable[node_input_cols + addl_input_cols]
 
         return input_data
 
@@ -161,6 +177,10 @@ class LocalExecutor:
 
                 if is_list:
                     col_dtype = list_val_dtype(col_series)
+                if hasattr(col_dtype, "as_numpy_dtype"):
+                    col_dtype = col_dtype.as_numpy_dtype()
+                elif hasattr(col_series, "numpy"):
+                    col_dtype = col_series[0].cpu().numpy().dtype
 
                 output_data_schema = output_col_schema.with_dtype(
                     col_dtype, is_list=is_list, is_ragged=is_list
@@ -215,12 +235,26 @@ class DaskExecutor:
         return {k: v for k, v in self.__dict__.items() if k != "client"}
 
     def transform(
-        self, ddf, nodes, output_dtypes=None, additional_columns=None, capture_dtypes=False
+        self, ddf, graph, output_dtypes=None, additional_columns=None, capture_dtypes=False
     ):
         """
         Transforms all partitions of a Dask Dataframe by applying the operators
         from a collection of Nodes
         """
+        nodes = []
+        if isinstance(graph, Graph):
+            nodes.append(graph.output_node)
+        elif isinstance(graph, Node):
+            nodes.append(graph)
+        elif isinstance(graph, list):
+            nodes = graph
+        else:
+            raise TypeError(
+                f"DaskExecutor detected unsupported type of input for graph: {type(graph)}."
+                " `graph` argument must be either a `Graph` object (preferred)"
+                " or a list of `Node` objects (deprecated, but supported for backward"
+                " compatibility.)"
+            )
 
         self._clear_worker_cache()
 
